Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Connection ¶
type Connection struct {
// contains filtered or unexported fields
}
func NewConnection ¶
func NewConnection(config ConnectionConfig) *Connection
func (*Connection) Close ¶
func (c *Connection) Close() error
func (*Connection) GetChannel ¶
func (c *Connection) GetChannel() *amqp091.Channel
func (*Connection) GetExchange ¶
func (c *Connection) GetExchange() string
func (*Connection) Initialize ¶
func (c *Connection) Initialize(name string) error
type ConnectionConfig ¶
type Listener ¶
type Listener struct {
RetryCount int
RetryTimeout time.Duration
DontSetupNack bool
// contains filtered or unexported fields
}
func NewListener ¶
func NewListener(conn *Connection, queueName string) *Listener
type PublishOptions ¶
type PublishOptions struct {
Persistent bool // Indicates if messages should be marked as persistent.
}
type Publisher ¶
type Publisher struct {
// contains filtered or unexported fields
}
func NewPublisher ¶
func NewPublisher(conn *Connection, queue string, options PublishOptions) *Publisher
NewPublisher creates a new instance of a Publisher. This function takes a connection manager, the name of the queue to publish messages to, and publishing options. It returns a pointer to a new Publisher instance.
type Usagi ¶
type Usagi struct {
ConnectionManager *Connection
}
func NewUsagi ¶
func NewUsagi(config ConnectionConfig) *Usagi
func (*Usagi) Initialize ¶
Click to show internal directories.
Click to hide internal directories.